@@ -1,10 +1,13 @@
+library(shiny)
+library(shinyStorePlus)
+
 ui <- fluidPage(
   #Initialize shinyStorePlus
   initStore(),
 
   # Application title
   titlePanel("Transfer browser link parameters to shiny input"),
-
+  tags$h3("To see this in action, append this to your browser link: ?data=pressure&name=obinna&num=50&outt=wowowow"),
   # Sidebar with a slider input for number of bins
   selectInput(
     inputId = "datasetbin",
